import os

from .file_mgr import copy_file, get_name, get_div, sep_block
from .core import run

# main update function
def update(filename, template_type):
    if not os.path.exists(filename):
        print("Error: The file \"{}\" does not exist. Please choose another filename.".format(filename))
    else:
        # copy the file to a new location
        name = get_name(filename,"_old")
        os.rename(filename,name)

        # read contents of file to user dict by separating relevant blocks
        with open(name,'r') as f:
            fl = list(f)
        macros = sep_block(fl,"file-specific macros")
        body = sep_block(fl,"document start")

        # strip last item of macros to avoid increasing whitespace in file
        if len(macros) >= 1:
            macros[-1] = macros[-1].rstrip()

        # rebuild file
        user = {'macros':macros,'contents':body}
        run(filename, template_type, user_macros=user)



import sys
import argparse

from .test import test
from .core import run
from .file_mgr import truncated_files
from .update import update

# main argument parser, after pre-checking info
def parse():
    parser = argparse.ArgumentParser(prog="texnew",description='An automatic LaTeX template creator.')
    parser.add_argument('target', metavar='output', type=str, nargs=1,
                                help='the name of the file you want to create')
    parser.add_argument('template_type', metavar='template', type=str, nargs=1,
                                help='the name of the template to use')

    parser.add_argument('-l', "--list", action="store_true", default=False, dest="lst",help="list existing templates and root folder")
    parser.add_argument('-c', "--check", action="store_true", default=False, dest="lst",help="check for errors in existing templates")
    parser.add_argument('-u', "--update", action="store_true", default=False, dest="update",help="update the specified file with the desired template")

    args = parser.parse_args()
    return (args.target[0], args.template_type[0], args.update)

def main():
    if "-l" in sys.argv:
        print("\nRoot Folder: {}/".format(rpath()))
        print("Existing templates:\n"+ "\t".join(truncated_files("share","templates")))
    elif "-c" in sys.argv:
        test()
    else:
        target, template_type, update = parse()
        if update:
            update(target, template_type)
        else:
            if not target.endswith(".tex"):
                target = target + ".tex"
            run(target, template_type)

# entry point for script
if __name__ == "__main__":
    main()



from setuptools import setup, find_packages
from texnew import __version__
def readme():
    with open('README.rst') as f:
        return f.read()

setup(
    name='texnew',
    version=__version__,
    description='Automatic LaTeX template mangement.',
    long_description=readme(),
    url='https://github.com/alexrutar/texnew',
    author='Alex Rutar',
    author_email='arutar@uwaterloo.ca',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3.7',
        'License :: OSI Approved :: MIT License'
        ],
    keywords='LaTeX template',
    license='MIT',
    packages=find_packages(),
    install_requires=[
        'pyyaml>=3.13'
        ],
    include_package_data=True,
    entry_points={'console_scripts': ['texnew = texnew.__main__:main']},
    zip_safe=False
    )

